==> bitwise-1.1.1.tgz: package/buffer/read.test.js <==
"use strict";

var _ = _interopRequireDefault(require("../"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test('without length and offset', function () {
  var buffer = new Buffer('AE37', 'hex');
  expect(_.default.buffer.read(buffer).join()).toBe(_.default.string.toBits('1010 1110 0011 0111').join());
});
test('without length, but offset', function () {
  var buffer = new Buffer('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 64).join()).toBe(_.default.string.toBits('1100 0100 1010 0110').join());
});
test('without length, but offset (odd start)', function () {
  var buffer = new Buffer('ED743E17', 'hex');
  expect(_.default.buffer.read(buffer, 12).join()).toBe(_.default.string.toBits('0100 0011 1110 0001 0111').join());
});
test('with offset and length', function () {
  var buffer = new Buffer('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 32, 24).join()).toBe(_.default.string.toBits('0010 1011 0100 0100 1110 0010').join());
});
test('with offset and length (odd end)', function () {
  var buffer = new Buffer('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 32, 30).join()).toBe(_.default.string.toBits('0010 1011 0100 0100 1110 0010 1011 01').join());
});
test('with offset and length (odd start and end)', function () {
  var buffer = new Buffer('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 34, 28).join()).toBe(_.default.string.toBits('1010 1101 0001 0011 1000 1010 1101').join());
});

==> bitwise-1.5.2.tgz: package/buffer/read.test.js <==
"use strict";

var _ = _interopRequireDefault(require("../"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

test('without length and offset', function () {
  var buffer = Buffer.from('AE37', 'hex');
  expect(_.default.buffer.read(buffer).join()).toBe(_.default.string.toBits('1010 1110 0011 0111').join());
});
test('without length, but offset', function () {
  var buffer = Buffer.from('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 64).join()).toBe(_.default.string.toBits('1100 0100 1010 0110').join());
});
test('without length, but offset (odd start)', function () {
  var buffer = Buffer.from('ED743E17', 'hex');
  expect(_.default.buffer.read(buffer, 12).join()).toBe(_.default.string.toBits('0100 0011 1110 0001 0111').join());
});
test('with offset and length', function () {
  var buffer = Buffer.from('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 32, 24).join()).toBe(_.default.string.toBits('0010 1011 0100 0100 1110 0010').join());
});
test('with offset and length (odd end)', function () {
  var buffer = Buffer.from('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 32, 30).join()).toBe(_.default.string.toBits('0010 1011 0100 0100 1110 0010 1011 01').join());
});
test('with offset and length (odd start and end)', function () {
  var buffer = Buffer.from('950225B12B44E2B4C4A6', 'hex');
  expect(_.default.buffer.read(buffer, 34, 28).join()).toBe(_.default.string.toBits('1010 1101 0001 0011 1000 1010 1101').join());
});
